mailr9394 - /1.3/test_suite/unit_tests/_prompt/test_molmol.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on August 26, 2009 - 11:28:
Author: bugman
Date: Wed Aug 26 11:28:13 2009
New Revision: 9394

URL: http://svn.gna.org/viewcvs/relax?rev=9394&view=rev
Log:
Wrote 5 arg unit tests for the molmol.macro_exec() user function.


Added:
    1.3/test_suite/unit_tests/_prompt/test_molmol.py
      - copied, changed from r9393, 
1.3/test_suite/unit_tests/_prompt/test_pymol.py

Copied: 1.3/test_suite/unit_tests/_prompt/test_molmol.py (from r9393, 
1.3/test_suite/unit_tests/_prompt/test_pymol.py)
URL: 
http://svn.gna.org/viewcvs/relax/1.3/test_suite/unit_tests/_prompt/test_molmol.py?p2=1.3/test_suite/unit_tests/_prompt/test_molmol.py&p1=1.3/test_suite/unit_tests/_prompt/test_pymol.py&r1=9393&r2=9394&rev=9394&view=diff
==============================================================================
--- 1.3/test_suite/unit_tests/_prompt/test_pymol.py (original)
+++ 1.3/test_suite/unit_tests/_prompt/test_molmol.py Wed Aug 26 11:28:13 2009
@@ -24,7 +24,7 @@
 from unittest import TestCase
 
 # relax module imports.
-from prompt.pymol import Pymol
+from prompt.molmol import Molmol
 from relax_errors import RelaxNoneStrError, RelaxNoneStrListNumError, 
RelaxStrError
 
 # Unit test imports.
@@ -32,15 +32,15 @@
 import fake_relax
 
 
-class Test_pymol(TestCase):
-    """Unit tests for the functions of the 'prompt.pymol' module."""
+class Test_molmol(TestCase):
+    """Unit tests for the functions of the 'prompt.molmol' module."""
 
     # Instantiate the user function class.
-    pymol_fns = Pymol(fake_relax.fake_instance())
+    molmol_fns = Molmol(fake_relax.fake_instance())
 
 
     def test_macro_exec_argfail_data_type(self):
         """The data_type arg test of the pymol.macro_exec() user function."""
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -49,11 +49,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxStrError, self.pymol_fns.macro_exec, 
data_type=data[1])
+            self.assertRaises(RelaxStrError, self.molmol_fns.macro_exec, 
data_type=data[1])
 
 
     def test_macro_exec_argfail_style(self):
         """The style arg test of the pymol.macro_exec() user function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -62,11 +62,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxStrError, self.pymol_fns.macro_exec, 
data_type='a', style=data[1])
+            self.assertRaises(RelaxStrError, self.molmol_fns.macro_exec, 
data_type='a', style=data[1])
 
 
     def test_macro_exec_argfail_colour_start(self):
-        """The colour_start arg test of the pymol.macro_exec() user 
function."""
+        """The colour_start arg test of the molmol.macro_exec() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -75,11 +75,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrListNumError, 
self.pymol_fns.macro_exec, data_type='a', style='x', colour_start=data[1])
+            self.assertRaises(RelaxNoneStrListNumError, 
self.molmol_fns.macro_exec, data_type='a', style='x', colour_start=data[1])
 
 
     def test_macro_exec_argfail_colour_end(self):
-        """The colour_end arg test of the pymol.macro_exec() user 
function."""
+        """The colour_end arg test of the molmol.macro_exec() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -88,11 +88,11 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrListNumError, 
self.pymol_fns.macro_exec, data_type='a', style='x', colour_end=data[1])
+            self.assertRaises(RelaxNoneStrListNumError, 
self.molmol_fns.macro_exec, data_type='a', style='x', colour_end=data[1])
 
 
     def test_macro_exec_argfail_colour_list(self):
-        """The colour_list arg test of the pymol.macro_exec() user 
function."""
+        """The colour_list arg test of the molmol.macro_exec() user 
function."""
 
         # Loop over the data types.
         for data in DATA_TYPES:
@@ -101,4 +101,4 @@
                 continue
 
             # The argument test.
-            self.assertRaises(RelaxNoneStrError, self.pymol_fns.macro_exec, 
data_type='a', style='x', colour_list=data[1])
+            self.assertRaises(RelaxNoneStrError, self.molmol_fns.macro_exec, 
@@ -32,15 +32,15 @@
 
     def test_macro_exec_argfail_data_type(self):
-        """The data_type arg test of the pymol.macro_exec() user function."""
+        """The data_type arg test of the molmol.macro_exec() user 
function."""
 
@@ -49,11 +49,11 @@
 
     def test_macro_exec_argfail_style(self):
-        """The style arg test of the pymol.macro_exec() user function."""
+        """The style arg test of the molmol.macro_exec() user function."""
 
         # Loop over the data types.
data_type='a', style='x', colour_list=data[1])




Related Messages


Powered by MHonArc, Updated Wed Aug 26 14:20:05 2009